From 9bc44fb0c8620383837d31db8e9ba92b6e44bf6c Mon Sep 17 00:00:00 2001
From: Lucas D Hedding <lucashedding@1463982.no-reply.drupal.org>
Date: Sat, 8 Jun 2013 13:33:36 -0500
Subject: [PATCH] Issue #2003330 by ericthelast, heddn | Dan Reinders: Rename
 Views method render_items() to renderItems().

---
 core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php   |    4 ++--
 .../views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php  |    2 +-
 .../views/lib/Drupal/views/Plugin/views/field/PrerenderList.php    |    4 ++--
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
index c45f57d..d2c0c9d 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
@@ -1142,7 +1142,7 @@ public function advancedRender($values) {
           $items[] = $this->renderText($alter);
         }
 
-        $value = $this->render_items($items);
+        $value = $this->renderItems($items);
       }
       else {
         $alter = array('phase' => VIEWS_HANDLER_RENDER_TEXT_PHASE_COMPLETELY) + $this->options['alter'];
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/PrerenderList.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/PrerenderList.php
index c222d1b..57aec1d 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/PrerenderList.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/PrerenderList.php
@@ -73,7 +73,7 @@ public function buildOptionsForm(&$form, &$form_state) {
    * When using advanced render, each possible item in the list is rendered
    * individually. Then the items are all pasted together.
    */
-  function render_items($items) {
+  protected function renderItems($items) {
     if (!empty($items)) {
       if ($this->options['type'] == 'separator') {
         return implode($this->sanitizeValue($this->options['separator'], 'xss_admin'), $items);
@@ -112,7 +112,7 @@ function get_items($values) {
    * Determine if advanced rendering is allowed.
    *
    * By default, advanced rendering will NOT be allowed if the class
-   * inheriting from this does not implement a 'render_items' method.
+   * inheriting from this does not implement a 'renderItem' method.
    */
   protected function allowAdvancedRender() {
     // Note that the advanced render bits also use the presence of
diff --git a/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php b/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
index 60b67e7..e533a9f 100644
--- a/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
+++ b/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
@@ -25,7 +25,7 @@
 class Field extends FieldPluginBase {
 
   /**
    * An array to store field renderable arrays for use by render_items.
    *
    * @var array
    */
@@ -620,7 +620,7 @@ public function submitGroupByForm(&$form, &$form_state) {
    * When using advanced render, each possible item in the list is rendered
    * individually. Then the items are all pasted together.
    */
-  function render_items($items) {
+  protected function renderItems($items) {
     if (!empty($items)) {
       if (!$this->options['group_rows']) {
         return implode('', $items);
@@ -25,7 +25,7 @@
 
   /**
-   * An array to store field renderable arrays for use by render_items.
+   * An array to store field renderable arrays for use by renderItems().
    *
    * @var array
-- 
1.7.10.4

